@@ -6,6 +6,7 @@ from sqlalchemy.orm import relationship
 
 from poindexter.models import Base
 from poindexter.models.Tag import Tag
+from poindexter.models.Domain import Domain
 
 
 Link_Tag_Table = Table(
@@ -18,11 +19,15 @@ Link_Tag_Table = Table(
 
 class LinkCreate(BaseModel):
   value: str
+  title: str
+  snippet: str
+  domain_id: int
   screenshot: str
 
 
 class Link(LinkCreate):
   id: int
+  domain: Domain
   tags: List[Tag]
   class Config:
     orm_mode = True
@@ -32,5 +37,9 @@ class LinkModel(Base):
   __tablename__ = 'links'
   id = Column(Integer, primary_key=True, index=True)
   value = Column(String)
+  title = Column(String)
+  snippet = Column(String)
   screenshot = Column(String)
+  domain_id = Column(Integer, ForeignKey("domains.id"))
+  domain = relationship("DomainModel")
   tags = relationship("TagModel", secondary=Link_Tag_Table)
